colorama: Cross-platform colored terminal text
==============================================

Description
-----------

Cross-platform colored terminal text

License
-------

Upstream Contact
----------------

https://pypi.org/project/colorama/

